<?php
/*
Plugin Name:    E-Connector for WooCommerce
Plugin URI:     https://wordpress.org/plugins/econnector-for-woocommerce
Description:    Additional functionality to enhance your e-connector experience
Version:        1.1.1
Author:         Vaisonet
Author URI:     https://www.vaisonet.com/
Developer:      Vincent Dubroeucq
Developer URI:  https://vincentdubroeucq.com/
Text Domain:    e-connector-for-woocommerce
Domain Path:    /languages
License:        GPL v3 or later
License URI:    https://www.gnu.org/licenses/gpl-3.0.html
Requires at least: 5.3
Requires PHP:      7.0
WC requires at least : 5.0
WC tested up to: 7.0.0
*/

defined( 'ABSPATH' ) || die();

define( 'E_CONNECTOR_FOR_WOOCOMMERCE_PATH', plugin_dir_path( __FILE__ ) );
define( 'E_CONNECTOR_FOR_WOOCOMMERCE_URL', plugin_dir_url( __FILE__ ) );
define( 'E_CONNECTOR_FOR_WOOCOMMERCE_VERSION', '1.1.1' );
define( 'E_CONNECTOR_FOR_WOOCOMMERCE_TEMPLATES_PATH', E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'templates/' );

add_action( 'plugins_loaded', 'e_connector_for_woocommerce_load_textdomain' );
/**
 * Load translations
 */
function e_connector_for_woocommerce_load_textdomain() {
    load_plugin_textdomain( 'e-connector-for-woocommerce', FALSE, basename( dirname( __FILE__ ) ) . '/languages' );
}

// register_activation_hook( __FILE__, 'e_connector_for_woocommerce_activation' );
/**
 * Activation procedure
 */
function e_connector_for_woocommerce_activation(){}


register_deactivation_hook( __FILE__, 'e_connector_for_woocommerce_deactivation' );
/**
 * Deactivation procedure
 */
function e_connector_for_woocommerce_deactivation(){
    if( $timestamp = wp_next_scheduled( 'e_connector_for_woocommerce_daily_tasks' ) ){
        wp_unschedule_event( $timestamp, 'e_connector_for_woocommerce_daily_tasks' );
    }
}

// register_uninstall_hook(__FILE__, 'e_connector_for_woocommerce_uninstallation' );
/**
 * Uninstall procedure
 */
function e_connector_for_woocommerce_uninstallation(){}

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'e_connector_for_woocommerce_plugin_action_links', 10, 4 );
/**
 * Adds plugin action links
 * 
 * @param   array   $actions  Available actions
 * @param   string  $file  Plugin file
 * @param   array   $data  $plugin data
 * @param   string  $context  Context
 * @return  array   $actions
 */
function e_connector_for_woocommerce_plugin_action_links( $actions, $file, $data, $context ){
    $actions['documentation'] = sprintf( 
        '<a href="%s" target="_blank" rel="nooepener noreferrer">%s</a>',
        esc_url( add_query_arg( 'tab', 'econnector', menu_page_url( 'wc-settings', false ) ) ),
        esc_html__( 'Documentation', 'e-connector-for-woocommerce' ) 
    );
    return $actions;
}

add_action( 'plugins_loaded', 'e_connector_for_woocommerce_init' );
/**
 * Loads core class and initialize it. 
 */ 
function e_connector_for_woocommerce_init(){
    if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
        require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-main.php';
        $econnector = new E_connector_For_Woocommerce\Main();
        $econnector->init();
    } else {
        add_action( 'admin_notices', 'e_connector_for_woocommerce_missing_notice' );
    }
}

/**
 * Adds a notice if WooCommerce is not installed
 */
function e_connector_for_woocommerce_missing_notice(){
    ?>
        <div class="notice notice-error is-dismissible">
            <p><?php _e( 'The plugin E-Connector for WooCommerce requires WooCommerce to be active to work properly. Please install or activate WooCommerce.', 'e-connector-for-woocommerce' ); ?></p>
        </div>
    <?php
}
