<?php
namespace E_connector_For_Woocommerce;
/**
 * Class for handling all content-related actions.
 */
class Admin_Pages implements Hookable {
    
    /**
     * SQLITE3 client database
     */
    protected $db = null;

    /**
     * Subpages to register
     */
    protected $subpages = array();

    /**
     * Constructor
     */
    public function __construct( $db = null ){
        $this->db        = $db;
        $this->subpages  = array(
            'product_prices' => array(
                'parent_slug' => 'woocommerce',
                'page_title'  => __( 'Product prices', 'e-connector-for-woocommerce' ),
                'menu_title'  => __( 'Product prices', 'e-connector-for-woocommerce' ),
                'capability'  => 'manage_options',
                'menu_slug'   => 'product_prices',
                'callback'    => array( $this, 'list_page_markup' ),
            ),
        );
    }

    /**
     * Returns the admin subpages
     * 
     * @return  array  Array of subpages arguments 
     */
    public function get_subpages(){
        return apply_filters( 'e_connector_for_woocommerce_admin_subpages', $this->subpages );
    }

    /**
     * Registers hooks
     */
    public function register_hooks(){
        add_action( 'admin_menu', array( $this, 'register_admin_pages' ), 15 );
        add_filter( 'set-screen-option', array( $this, 'set_screen_option' ), 10, 3 );
        add_filter( 'woocommerce_get_settings_pages', array( $this, 'register_woocommerce_pages' ) );
        add_action( 'woocommerce_settings_econnector', array( $this, 'woocommerce_settings_econnector_documentation' ) );
    }

    /**
     * Registers the admin pages
     */
    public function register_admin_pages(){
        if( $this->db && $this->db->is_active() && e_connector_for_woocommerce_should_use_db()  ){
            foreach ( $this->get_subpages() as $slug => $args ) {
                $hook = add_submenu_page(
                    $args['parent_slug'],
                    $args['page_title'],
                    $args['menu_title'],
                    $args['capability'],
                    $args['menu_slug'],
                    $args['callback']
                );
                add_action( 'load-' . $hook, array( $this, "setup_${hook}_screen" ) );
            }
        }
    }

    /**
     * Registers the new Woocommerce page
     * 
     * @param   array  $pages  Registered Woocommerce admin pages
     * @return  array  $pages
     */
    public function register_woocommerce_pages( $pages ){
        require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-settings-page.php';
        $pages[] = new Settings_Page();
        return $pages;
    }

    /**
     * Sets up the client discount listing page
     */
    public function setup_woocommerce_page_product_prices_screen(){
        $screen = get_current_screen();
        if( 'woocommerce_page_product_prices' === $screen->id ){
            
            // Add screen options
            add_screen_option( 'per_page', array(
                'label'		=>	__( 'Products per page', 'e-connector-for-woocommerce' ),
                'default'	=>	20,
                'option'	=>	'products_per_page'
            ) );
            
            // Loads the table
            if ( ! class_exists( 'WP_List_Table' ) ) {
                require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
            }

            require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-product-prices-table.php';
            $this->table = new Product_Prices_Table( $this->db );
        }
    }


    /**
     * Save the screen option setting.
     *
     * @param string $status The default value for the filter. Using anything other than false assumes you are handling saving the option.
     * @param string $option The option name.
     * @param array  $value  Whatever option you're setting.
     */
    function set_screen_option( $status, $option, $value ) {
        if ( 'products_per_page' === $option ) {
            return $value;
        }
    }

    
    /**
     * Contents of the E-Connector documentation section.
     */
    public function woocommerce_settings_econnector_documentation(){
		global $current_section;
        
        if( empty( $current_section ) || 'documentation' !== $current_section ){
            return;
        }

        printf( '<h2>%s</h2>', __( 'E-Connector Documentation', 'e-connector-for-woocommerce' ) );

        $filename  = sprintf( 'documentation-%s.md', get_user_locale() );
        $docs_path = E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'documentation/';
        $docs_file = file_exists( $docs_path . 'documentation.md' ) ? $docs_path . 'documentation.md' : false;
        if( file_exists( $docs_path . $filename ) ) {
            $docs_file = $docs_path . $filename;
        }

        if( $docs_file ){
            require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'lib/parsedown.php';
            $raw       = file_get_contents( $docs_file );
            $Parsedown = new \Parsedown();
            $Parsedown->setSafeMode( true );
            $Parsedown->setMarkupEscaped( true );
            $parsed    = $Parsedown->text( $raw );
            $content   = str_replace( 'E_CONNECTOR_FOR_WOOCOMMERCE_URL', E_CONNECTOR_FOR_WOOCOMMERCE_URL, $parsed );
            echo wp_kses_post( $content );
        }
    }

    /**
     * List table pages display callback
     */
    public function list_page_markup(){
        $this->table->prepare_items();
        ?>
            <div class="wrap">
                <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
                <form method="POST">
                    <?php 
                        $this->table->search_box( 'search', 'search_id' );
                        $this->table->display();
                    ?>
                </form>
            </div>
        <?php
    }
}