<?php
namespace E_connector_For_Woocommerce;
/**
 * Email Manager class.
 * 
 * Registers and triggers emails.
 */
class Email_Manager {
    
    /**
     * Registers hooks
     */
    public function register_hooks(){
        add_filter( 'woocommerce_email_classes', array( $this, 'register_emails' ), 10, 1 );
        add_filter( 'woocommerce_email_attachments', array( $this, 'register_attachment' ), 10, 4 );
    }


    /**
     * Add a custom email to the list of emails WooCommerce should load
     *
     * @param   array  $email_classes  Available email classes
     * @return  array  $email_classes  
     */
    function register_emails( $email_classes ){
        require_once( E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/emails/class-wc-email-new-document.php' );
        require_once( E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/emails/class-wc-email-customer-new-document.php' );
        $email_document_new = array(
            'WC_Email_New_Document' => new WC_Email_New_Document(),
            'WC_Email_Customer_New_Document' => new WC_Email_Customer_New_Document(),
        );
        $email_classes = \e_connector_for_woocommerce_array_insert( $email_classes, 'WC_Email_Failed_Order', $email_document_new );
        return $email_classes;
    }

    /**
     * Adds relevant attachment to emails
     * 
     * @param  array             $attachments  Existing attachments
     * @param  int               $email_id     Slug of the email
     * @param  WP_Post|WC_Order  $object       Document, or WC_Order
     */
    function register_attachment( $attachments, $email_id, $object, $email ) {
        if ( ! isset( $email_id ) ) {
            return $attachments;
        }
        if( in_array( $email_id, array( 'customer_new_document', 'new_document' ) ) ){
            $send_attachment = $email->get_option( 'send_attachment' );
            if( $send_attachment && 'yes' === $send_attachment ){
                $file_path = get_attached_file( (int) $object->ID );
                if( $file_path ){
                    $attachments[] = $file_path;
                }
            }
        }
        return $attachments;
    }
}