<?php
namespace E_connector_For_Woocommerce;
/**
 * Core class.
 * 
 * Loads main files and register hooks.
 */
class Main {

    /**
     * Array of dependencies objects
     */
    private $dependencies = array();

    /**
     * SQLITE3 database, if it exists
     */
    private $db = null;
    
    /**
     * Loads required files, and register hooks. 
     */
    public function init(){
        $this->load_dependencies();
        $this->register_hooks();
    }

    /**
     * Loads necessary files and register them as dependencies
     */
    private function load_dependencies(){
        require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/interface-hookable.php';
        require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/functions.php';
        
        // Needed both on frontend and backend
        if( e_connector_for_woocommerce_should_use_db() ){
            if( class_exists( 'SQLITE3' ) ){
                require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-e-connector-db.php';
                require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-product-manager.php';
                $this->db = new E_Connector_Db();
                $this->dependencies['product-manager'] = new Product_Manager( $this->db );
            } else {
                error_log( 'SQLITE3 does not seem to be activated. Please check your PHP configuration.' );
            }
        }

        require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-endpoints.php';
        require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-account-page.php';
        require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-email-manager.php';
        require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-content-manager.php';
        require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-task-manager.php';
        $this->dependencies['endpoints']       = new Endpoints();
        $this->dependencies['account-page']    = new Account_Page();
        $this->dependencies['emails']          = new Email_Manager();
        $this->dependencies['content-manager'] = new Content_Manager();
        $this->dependencies['task-manager']    = new Task_Manager( $this->db );
        
        if( is_admin() ){
            // Only needed in the admin
            require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-user-manager.php';
            require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-admin-pages.php';
            $this->dependencies['admin-pages']  = new Admin_Pages( $this->db );
            $this->dependencies['user-manager'] = new User_Manager( $this->db );
        }
    }

    /**
     * Hooks all the dependencies
     */
    private function register_hooks(){
        add_action( 'wp_enqueue_scripts', array( $this, 'register_scripts' ) );
        foreach ( $this->dependencies as $key => $dep ) {
            $dep->register_hooks();
        }
    }

    /**
     * Loads scripts and styles
     */
    public function register_scripts(){
        wp_register_style( 'econnector', E_CONNECTOR_FOR_WOOCOMMERCE_URL . 'assets/css/style.css', array(), E_CONNECTOR_FOR_WOOCOMMERCE_VERSION );
        if( is_account_page() ){
            wp_enqueue_style( 'econnector' );
        }
    }
}
