<?php
namespace E_connector_For_Woocommerce;
/**
 * Class to display the distant clients table.
 */
class Product_Prices_Table extends \WP_List_Table {

    /**
     * Total number of products
     */
    protected $total;

    /**
     * Database instance
     */
    protected $db = null;

    /** 
     * Class constructor 
     */
    public function __construct( $db ) {
        $this->db = $db;
        parent::__construct( [
            'singular' => 'client', 
            'plural'   => 'clients', 
            'ajax'     => false
        ] );
    }

    /**
     * Gets an array of columns to display.
     *
     * @return array
     */
    public function get_columns() {
        $columns = array(
            'GPM_id'               => __( 'ID (ERP)', 'e-connector-for-woocommerce' ),
            'source'               => __( 'Source', 'e-connector-for-woocommerce' ),
            'PriceListId'          => __( 'Price list ID', 'e-connector-for-woocommerce' ),
            'product_erp_id'       => __( 'Product ID (ERP)', 'e-connector-for-woocommerce' ),
            'product_erp_price'    => __( 'Product price (ERP)', 'e-connector-for-woocommerce' ),
            'prix_de_base'         => __( 'Base price', 'e-connector-for-woocommerce' ),
            'reduction_type'       => __( 'Discount type', 'e-connector-for-woocommerce' ),
            'price'                => __( 'Price or discount', 'e-connector-for-woocommerce' ),
            'prix_definitive'      => __( 'Final price', 'e-connector-for-woocommerce' ),
            'customer_erp_id'      => __( 'Client ID (ERP)', 'e-connector-for-woocommerce' ),
            'customer_cms_id'      => __( 'Client ID (CMS)', 'e-connector-for-woocommerce' ),
            'group_name'           => __( 'Group name', 'e-connector-for-woocommerce' ),
            'from_quantity'        => __( 'Minimum quantity', 'e-connector-for-woocommerce' ),
            'fromSTR'              => __( 'Discount start date', 'e-connector-for-woocommerce' ),
            'toSTR'                => __( 'Discount end date', 'e-connector-for-woocommerce' ),
            'id_product_attribute' => __( 'Product attributes ID', 'e-connector-for-woocommerce' ),
            'id_currency'          => __( 'Currency', 'e-connector-for-woocommerce' ),
            'country_iso2'         => __( 'Country', 'e-connector-for-woocommerce' ),
        );   
        return $columns;
    }

    /**
     * Gets an array of columns to display.
     *
     * @return array
     */
    protected function get_sortable_columns() {
        $columns = array(
            'GPM_id'               => array( 'GPM_id' ),
            'product_erp_id'       => array( 'product_erp_id' ),
            'product_erp_price'    => array( 'product_erp_price' ),
            'price'                => array( 'price' ),
            'reduction_type'       => array( 'reduction_type' ),
            'customer_erp_id'      => array( 'customer_erp_id' ),
            'customer_cms_id'      => array( 'customer_cms_id' ),
            'group_name'           => array( 'group_name' ),
            'from_quantity'        => array( 'from_quantity' ),
            'fromSTR'              => array( 'fromSTR' ),
            'toSTR'                => array( 'toSTR' ),
            'prix_de_base'         => array( 'prix_de_base' ),
            'id_product_attribute' => array( 'id_product_attribute' ),
        );   
        return $columns;
    }

    /**
     * Render a column when no column specific method exists.
     *
     * @param array  $item_id
     * @param string $column_name
     *
     * @return mixed
     */
    public function column_default( $item, $column_name ) {
        switch ( $column_name ) {
            default: 
                return esc_html( $item[$column_name] );
                break;
        }
    }

    /**
     * Handles data query and filter, sorting, and pagination.
     */
    public function prepare_items() {

        $this->items = array();
        $this->_column_headers = $this->get_column_info();
    
        $per_page = $this->get_items_per_page( 'products_per_page', 20 );
        $page     = $this->get_pagenum();
        $order_by = ! empty( $_GET['orderby'] ) ? sanitize_text_field( $_GET['orderby'] ) : '';
        $order    = ! empty( $_GET['order'] ) ? sanitize_text_field( $_GET['order'] ) : '';
        $search   = ! empty( $_REQUEST['s'] ) ? sanitize_text_field( $_REQUEST['s'] ) : '';
        
        if( $search ) $_SERVER['REQUEST_URI'] = add_query_arg( 's', $search, $_SERVER['REQUEST_URI'] );

        $this->items = $this->get_prices( $per_page, $page, $order_by, $order, $search );
        $this->total = $this->get_total_products( $search );
        
        $this->set_pagination_args( [
            'total_items' => (int) $this->total,
            'per_page'    => (int) $per_page,
            'total_pages' => ceil( $this->total / (int) $per_page ),
        ] );    
    }

    /**
     * Fetches prices for the current page
     * 
     * @param   int     $per_page      Number of prices to fetch
     * @param   int     $current_page  Number of the current page
     * @param   string  $order_by      The sorting parameter
     * @param   string  $order         Ascending or descending
     * @param   string  $search        The search string if provided
     * @return  array                  Array of prices
     */
    public function get_prices( $per_page, $current_page, $order_by = '', $order = '', $search = '' ){       
        $offset  = (int) ( $current_page - 1 ) * $per_page;
        $prices = $this->db && $this->db->is_active() ? $this->db->fetch( 'prices', $per_page, $offset, $order_by, $order, $search ) : [];
        return $prices;
    }

    /**
     * Retrieves the total number of product families, or fetches it.
     * 
     * @param   string  $search          The search string if provided
     * @return  int     $total_families  Total number of product families
     */
    public function get_total_products( $search = '' ){
        $total = $this->db && $this->db->is_active() ? $this->db->fetch_products_count( $search ) : 0;
        return $total;
    }
}