<?php
namespace E_connector_For_Woocommerce;
/**
 * Class for handling admin settings page.
 */
class Settings_Page extends \WC_Settings_Page {

    /**
     * Constructor
     */
    public function __construct(){
        $this->id       = 'econnector';
        $this->label    = __( 'E-Connector', 'e-connector-for-woocommerce' );
        $this->settings = array(
            'general' => array(
                array(
					'id'    => 'e_connector_for_woocommerce_general',
					'title' => __( 'General Settings', 'e-connector-for-woocommerce' ),
					'type'  => 'title',
				),
				array(
					'id'       => 'e_connector_settings[should_use_db]',
					'title'    => __( 'Use external prices DB', 'e-connector-for-woocommerce' ),
					'type'     => 'checkbox',
					'desc'     => __( 'Check to read product prices from external DB.', 'e-connector-for-woocommerce' ),
					'desc_tip' => false,
				),
				array(
					'id'   => 'e_connector_for_woocommerce_general',
					'type' => 'sectionend'
				),
            ),
            'documentation' => array(),
        ); 
        parent::__construct();
    }

    /**
     * Registers the different sections.
     * 
     * @return  array  $sections
     */
    public function get_sections() {
		$sections = array(
			'general'       => __( 'General', 'e-connector-for-woocommerce' ),
			'documentation' => __( 'Documentation', 'e-connector-for-woocommerce' )
		);
		return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
	}

    /**
     * Registers the different settings
     * 
     * @return  $array  $settings
     */
    public function get_settings() {
		global $current_section;
		$settings = $this->get_section_settings( $current_section );
		return apply_filters( 'woocommerce_get_settings_' . $this->id, $settings );
	}

    /**
     * Returns specific section settings
     * 
     * @param   string  $section  Section to get settings for
     * @return  array   $settings
     */
    public function get_section_settings( $section = '' ){
        $section  = ! empty( $section ) ? $section : 'general';
        $settings = array_key_exists( $section, $this->settings ) ? $this->settings[$section] : array();
        return $settings;
    }
}