<?php
namespace E_connector_For_Woocommerce;
/**
 * Class for handling all automated tasks.
 */
class Task_Manager implements Hookable {

    /**
     * SQLITE3 DB instance
     */
    protected $db = null;

    /** 
     * Class constructor 
     */
    public function __construct( $db ) {
        $this->db = $db;
    }

    /**
     * Registers hooks
     */
    public function register_hooks(){
        add_action( 'init', array( $this, 'schedule_tasks' ) );
        add_action( 'e_connector_for_woocommerce_daily_tasks', array( $this, 'e_connector_for_woocommerce_daily_tasks' ) );
    }

    /**
     * Checks for products updated yesterday
     */
    public function e_connector_for_woocommerce_daily_tasks(){
        $db_url = get_transient( 'econnector_db_url' );
        if( $db_url && e_connector_for_woocommerce_should_use_db() ){
            if( ! $this->db ){
                require_once E_CONNECTOR_FOR_WOOCOMMERCE_PATH . 'inc/class-e-connector-db.php';
                $this->db = new E_Connector_Db();
            }
            if( $this->db ){
                $result = $this->db->update_db( $db_url );
                if( is_wp_error( $result ) ){
                    error_log( $result->get_error_message() );
                }
                if( $result ) {
                    error_log( 'Database successfull updated' );
                    delete_transient( 'econnector_db_url' );
                } else {
                    error_log( 'There was an error uploading SQLITE database file.' );
                }
            }
        }
    }

    /**
     * Schedules automated tasks
     */
    public function schedule_tasks(){
        if ( ! wp_next_scheduled( 'e_connector_for_woocommerce_daily_tasks' ) ) {
            wp_schedule_event( strtotime( 'tomorrow midnight' ), 'daily', 'e_connector_for_woocommerce_daily_tasks' );
        }
    }
}