<?php
namespace E_connector_For_Woocommerce;
/**
 * Class for handling all user-related actions.
 */
class User_Manager implements Hookable {

    /**
     * Database instance
     */
    protected $db = null;

    /** 
     * Class constructor 
     */
    public function __construct( $db ){
        $this->db = $db;
    }

    /**
     * Registers hooks
     */
    public function register_hooks(){
        add_action( 'show_user_profile', array( $this, 'user_profile_fields' ) );
        add_action( 'edit_user_profile', array( $this, 'user_profile_fields' ) );
        add_action( 'user_new_form', array( $this, 'user_profile_fields' ) );
        add_action( 'personal_options_update', array( $this, 'save_user_profile_fields' ) );
        add_action( 'edit_user_profile_update', array( $this, 'save_user_profile_fields' ) );
        add_action( 'user_register', array( $this, 'save_user_profile_fields' ) );
    }


    /**
     * Add fields on user profile pages
     * 
     * @param  WP_User  $user
     */
    public function user_profile_fields( $user ) {
        $customer_group = is_a( $user, 'WP_User' ) ? get_user_meta( (int) $user->ID, 'econnector_customer_group', true ) : '';
        $groups         = $this->db && $this->db->is_active() ? array_filter( array_unique( wp_list_pluck( $this->db->fetch_group_name_values(), 'group_name' ) ) ) : array();
        if( ! empty( $groups ) ) : ?>
            <h2><?php esc_html_e( 'E-Connector user fields', 'e-connector-for-woocommerce' ); ?></h2>
            <table class="form-table">
                <tr>
                    <th><label for="econnector_customer_group"><?php esc_html_e( 'User group name', 'e-connector-for-woocommerce' ); ?></label></th>
                    <td>
                        <select id="econnector_customer_group" name="econnector_customer_group">
                            <option value=""><?php esc_html_e( 'No group', 'e-connector-for-woocommerce' ); ?></option>
                            <?php foreach ( $groups as $key => $group_name ) : ?>
                                <option value="<?php echo esc_attr( $group_name ); ?>" <?php selected( $customer_group, $group_name ); ?>><?php echo esc_html( $group_name ); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </td>
                </tr>
            </table>
        <?php endif;
    }

    /**
     * Saves our custom user fields
     * 
     * @param  int  $user_id
     */
    function save_user_profile_fields( $user_id ) {
        if ( ! current_user_can( 'edit_user', $user_id ) ) return;
        $customer_group = isset( $_POST['econnector_customer_group'] ) ? sanitize_title( $_POST['econnector_customer_group'] ) : ''; 
        update_user_meta( $user_id, 'econnector_customer_group', sanitize_title( $customer_group ) );
    }
}
