<?php
namespace E_connector_For_Woocommerce;
/**
 * Registers and handle new REST API endpoint for uploading databases.
 */
class WC_REST_DB_Controller extends WC_REST_Uploads_Controller {

	/**
	 * REST base for the ressource
	 */
	protected $rest_base;

	/**
	 * Initializes the controller
	 */
	public function __construct(){
		parent::__construct();
		$this->rest_base = 'db';
	}

	/**
	 * Registers the REST routes
	 */
	public function register_routes() {
		register_rest_route( $this->namespace, '/' . $this->rest_base,
			array(
				'methods'   => \WP_REST_Server::EDITABLE,
				'callback'  => array( $this, 'store_db_url' ),
				'permission_callback' => array( $this, 'upload_item_permissions_check' ),
				'args'      => array(
					'db_url' => array(
						'required'          => true,
						'validate_callback' => array( $this, 'validate_param' ),
					),
				)
			)
		);
	}

	/**
	 * Validates POST request parameters
	 * 
	 * @param   string           $value    Value to validate
	 * @param   WP_REST_Request  $request  Request object  
	 * @param   string           $key      Request parameter key
	 * @return  bool             $valid    Whether value is valid
	 */
	public function validate_param( $value, $request, $key ){
		switch ( $key ) {
			case 'db_url':
				return esc_url_raw( $value );
				break;
		}
		return false;
	}

	/**
	 * Handler for the POST request
	 * @param  WP_REST_Request  $request  Request object
	 */
	public function store_db_url( $request ) {		
		$db_url  = esc_url( $request->get_param( 'db_url' ) );
		$success = false;

		if( $db_url ){
			$success = set_transient( 'econnector_db_url', $db_url, DAY_IN_SECONDS );
			if( ! $success ) \error_log( 'Transient econnector_db_url could not be updated.' );
		} else {
			\error_log( 'Param db_url was missing in request.' );
		}

		$upload_dir     = wp_upload_dir();
        $uploads_subdir = trailingslashit( $upload_dir['basedir'] ) . trailingslashit( $this->uploads_subdir );
		if( ! is_dir( $uploads_subdir ) ) mkdir( $uploads_subdir, 0705 );
		
		$this->maybe_install_protection( 'index.php' );
		$this->maybe_install_protection( '.htaccess' );
		return $success;
	}
}