<?php
namespace E_connector_For_Woocommerce;
/**
 * Class WC_Email_Document_New file.
 * 
 * Controls the email sent when a new document is available
 */
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'WC_Email_Customer_New_Document' ) ) :

	class WC_Email_Customer_New_Document extends \WC_Email {

		/**
		 * Constructor.
		 */
		public function __construct() {
			$this->id             = 'customer_new_document';
			$this->customer_email = true;
			$this->title          = __( 'New document available - Customer', 'e-connector-for-woocommerce' );
			$this->description    = __( 'Email the customer receives when a document is available in his account.', 'e-connector-for-woocommerce' );
			$this->template_base  = E_CONNECTOR_FOR_WOOCOMMERCE_TEMPLATES_PATH;
			$this->template_html  = 'emails/customer-new-document.php';
			$this->template_plain = 'emails/plain/customer-new-document.php';
            $this->subject        = __( 'A new document is available in your account.', 'e-connector-for-woocommerce' );
            $this->heading        = __( 'A new document is available in your account.', 'e-connector-for-woocommerce' );
			
			// Call parent constructor.
			parent::__construct();
		}

		/**
		 * Trigger the sending of this email.
		 *
		 * @param  int  $document_id  The document ID
		 * @param  int  $user_id      Owner of the document.
		 */
		public function trigger( $document_id, $user_id = false ) {
            $this->setup_locale();
			$this->object = get_post( $document_id );

			if( ! $user_id ){
				$user_id = get_post_meta( $document_id, '_econnector_owner', true );
			}
			if( ! $user_id ){
				return false;
			}

			$userdata = get_userdata( $user_id );
			$this->recipient = ! empty( $userdata->user_email ) ? $userdata->user_email : '';

			if ( $this->is_enabled() && $this->get_recipient() ) {
				$this->send( $this->get_recipient(), $this->get_subject(), $this->get_content(), $this->get_headers(), $this->get_attachments() );
			}
            
			$this->restore_locale();
		}

		/**
		 * Get content html.
		 *
		 * @return string
		 */
		public function get_content_html() {
			return wc_get_template_html( 
                $this->template_html, 
                array(
					'document'           => $this->object,
					'email_heading'      => $this->get_heading(),
					'additional_content' => $this->get_additional_content(),
					'sent_to_admin'      => false,
					'plain_text'         => false,
					'email'              => $this,
				),
                '',
				$this->template_base
			);
		}

		/**
		 * Get content plain.
		 *
		 * @return string
		 */
		public function get_content_plain() {
			return wc_get_template_html(
				$this->template_plain,
				array(
					'document'           => $this->object,
					'email_heading'      => $this->get_heading(),
					'additional_content' => $this->get_additional_content(),
					'sent_to_admin'      => false,
					'plain_text'         => true,
					'email'              => $this,
				),
				'',
				$this->template_base
			);
		}

		/**
		 * Initialise settings form fields.
		 */
		public function init_form_fields() {
			parent::init_form_fields();
			$this->form_fields['send_attachment'] = array(
				'title'   => __( 'Attachments', 'e-connector-for-woocommerce' ),
				'type'    => 'checkbox',
				'label'   => __( 'Attach documents to email ?', 'e-connector-for-woocommerce' ),
				'default' => 'yes',
			);
		}
	}
endif;

