<?php
/**
 * Admin new document email
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/admin-new-document.php.
 *
 * @param  WP_Post  $document  New document 
 * @see https://docs.woocommerce.com/document/template-structure/
 */
defined( 'ABSPATH' ) || exit;

$document_id   = (int) $document->ID;
$attached_file = basename( get_attached_file( $document_id ) );
$document_name = ! empty( $attached_file ) ? $attached_file : $document->post_title;
$document_edit_url  = get_edit_post_link( $document_id );
$document_edit_link = ! empty( $document_edit_url ) ? sprintf( '<a href="%s">%s</a>', esc_url( $document_edit_url ), esc_html( $document_name ) ) : esc_html( $document_name );

$owner_id        = get_post_meta( $document_id, '_econnector_owner', true );
$owner_data      = (int) $owner_id ? get_userdata( $owner_id ) : false;
$owner_login     = $owner_data ? $owner_data->user_login : false;
$owner_edit_url  = get_edit_user_link( $owner_id );
$owner_edit_link = ! empty( $owner_edit_url ) ? sprintf( '<a href="%s">%s</a>', esc_url( $owner_edit_url ), esc_html( $owner_login ) ) : esc_html( $owner_login );
$send_attachment = $email->get_option( 'send_attachment' );

$message = sprintf(
	/* translators: %1$s: name of the document, $2$s owner of the document */ 
	__( 'A new document named <strong>%1$s</strong> has been uploaded, and its owner set to <strong>%2$s</strong>.', 'e-connector-for-woocommerce' ),
	$document_edit_link,
	$owner_edit_link
);
if( $send_attachment && 'yes' === $send_attachment ){
	$message .= ' ' . __( 'You can find the document attached to this email.', 'e-connector-for-woocommerce' );
}

/*
 * @hooked WC_Emails::email_header() Output the email header
 */
do_action( 'woocommerce_email_header', $email_heading, $email );

printf( '<p>%s</p>', $message );

/**
 * Show user-defined additional content - this is set in each email's settings.
 */
if ( $additional_content ) {
	echo wp_kses_post( wpautop( wptexturize( $additional_content ) ) );
}

/*
 * @hooked WC_Emails::email_footer() Output the email footer
 */
do_action( 'woocommerce_email_footer', $email );

